@@ -25,12 +25,11 @@
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QCoreApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QCoreApplication::setAttribute(Qt::AA_DisableSessionManager, true);
 
-#ifdef Q_OS_ANDROID
+#if defined Q_OS_ANDROID
     QGuiApplication app(argc, argv);
+
     if (!MAUIAndroid::checkRunTimePermissions({"android.permission.WRITE_EXTERNAL_STORAGE",
                                                "android.permission.READ_CALL_LOG",
                                                "android.permission.SEND_SMS",
@@ -43,9 +42,10 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QApplication app(argc, argv);
 #endif
 
+    qDebug() << "APP LOADING SPEED TESTS" << 1;
+
     app.setOrganizationName(QStringLiteral("Maui"));
     app.setWindowIcon(QIcon("://communicator.svg"));
-    MauiApp::instance()->setIconName("qrc:/communicator.svg");
 
     KLocalizedString::setApplicationDomain("communicator");
     KAboutData about(
@@ -58,6 +58,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     about.setProgramLogo(app.windowIcon());
 
     KAboutData::setApplicationData(about);
+    MauiApp::instance()->setIconName("qrc:/communicator.svg");
 
     QCommandLineParser parser;
     parser.process(app);
@@ -67,6 +68,8 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     QQmlApplicationEngine engine;
 
+    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
+
     engine.addImageProvider("contact", new ContactImage(QQuickImageProvider::ImageType::Image));
     qmlRegisterType<ContactsModel>(COMMUNICATOR_URI, 1, 0, "ContactsList");
     qmlRegisterType<Communicator>(COMMUNICATOR_URI, 1, 0, "Communicator");
